@@ -76,7 +76,7 @@ class MPImage():
                  key_events = False,
                  auto_size = False,
                  report_size_changes = False):
-        import multiprocessing
+        from MAVProxy.modules.lib import multiproc
 
         self.title = title
         self.tabs = tabs
@@ -91,14 +91,14 @@ class MPImage():
         self.menu = None
         self.popup_menu = None
 
-        self.in_queue = multiprocessing.Queue()
-        self.out_queue = multiprocessing.Queue()
+        self.in_queue = multiproc.Queue()
+        self.out_queue = multiproc.Queue()
 
         self.default_menu = MPMenuSubMenu('View',
                                           items=[MPMenuItem('Fit Window', 'Fit Window', 'fitWindow'),
                                                  MPMenuItem('Full Zoom',  'Full Zoom', 'fullSize')])
 
-        self.child = multiprocessing.Process(target=self.child_task)
+        self.child = multiproc.Process(target=self.child_task)
         self.child.start()
         self.set_popup_menu(self.default_menu)
 
